Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6926)

Unified Diff: chrome/browser/task_manager/task_manager_resource_providers.h

Issue 10113005: Remove EPM:all_hosts_ and use all_extension_views_ instead. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Comments addressed Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/task_manager/task_manager_resource_providers.h
diff --git a/chrome/browser/task_manager/task_manager_resource_providers.h b/chrome/browser/task_manager/task_manager_resource_providers.h
index 62497576bb2c308ee980e1f940ee7f67fdfc3e24..e3299e99a017a06c385eb8f58aeae7177512b520 100644
--- a/chrome/browser/task_manager/task_manager_resource_providers.h
+++ b/chrome/browser/task_manager/task_manager_resource_providers.h
@@ -22,7 +22,6 @@
class BackgroundContents;
class BalloonHost;
class Extension;
-class ExtensionHost;
class TabContentsWrapper;
namespace content {
@@ -344,7 +343,8 @@ class TaskManagerChildProcessResourceProvider
class TaskManagerExtensionProcessResource : public TaskManager::Resource {
public:
- explicit TaskManagerExtensionProcessResource(ExtensionHost* extension_host);
+ explicit TaskManagerExtensionProcessResource(
+ content::RenderViewHost* render_view_host);
virtual ~TaskManagerExtensionProcessResource();
// TaskManager::Resource methods:
@@ -370,7 +370,7 @@ class TaskManagerExtensionProcessResource : public TaskManager::Resource {
// The icon painted for the extension process.
static SkBitmap* default_icon_;
- ExtensionHost* extension_host_;
+ content::RenderViewHost* render_view_host_;
// Cached data about the extension.
base::ProcessHandle process_handle_;
@@ -402,13 +402,15 @@ class TaskManagerExtensionProcessResourceProvider
private:
virtual ~TaskManagerExtensionProcessResourceProvider();
- void AddToTaskManager(ExtensionHost* extension_host);
- void RemoveFromTaskManager(ExtensionHost* extension_host);
+ void AddToTaskManager(content::RenderViewHost* render_view_host);
+ void RemoveFromTaskManager(content::RenderViewHost* render_view_host);
TaskManager* task_manager_;
- // Maps the actual resources (ExtensionHost*) to the Task Manager resources.
- std::map<ExtensionHost*, TaskManagerExtensionProcessResource*> resources_;
+ // Maps the actual resources (content::RenderViewHost*) to the Task Manager
+ // resources.
+ std::map<content::RenderViewHost*,
+ TaskManagerExtensionProcessResource*> resources_;
// Maps the pids to the resources (used for quick access to the resource on
// byte read notifications).

Powered by Google App Engine
This is Rietveld 408576698